@@ -16,7 +16,8 @@
 extern int sprintf();
 #endif
 #else
-#if !(defined(MSDOS) || defined(NeXT) || defined(ultrix) || defined(linux))
+#if !(defined(MSDOS) || defined(NeXT) || defined(ultrix) || defined(linux) \
+|| defined(__386BSD__) || defined(SOLARIS))
 extern char *sprintf();
 #endif
 #endif
@@ -34,7 +35,7 @@ extern int NO_SAVE;
    within creatures() via place_monster() and summon_monster() */
 extern int hack_monptr;
 
-extern int16 log_index;		/* Index to log file. -CJS- */
+extern int16 log_index;			/* Index to log file. -CJS- */
 extern vtype died_from;
 extern vtype savefile;			/* The save file. -CJS- */
 
@@ -44,24 +45,26 @@ extern int find_cut;			/* Cut corners on a run */
 extern int find_examine;		/* Check corners on a run */
 extern int find_prself;			/* Print yourself on a run (slower) */
 extern int find_bound;			/* Stop run when the map shifts */
-extern int prompt_carry_flag;		/* auto-pickupobjects */
-extern int show_weight_flag;		/* Display weights in inventory */
+extern int prompt_carry_flag;	/* auto-pickupobjects */
+extern int show_weight_flag;	/* Display weights in inventory */
 extern int show_equip_weight_flag;	/* Display weights in equip list -CWS */
 extern int highlight_seams;		/* Highlight magma and quartz */
-extern int find_ignore_doors;		/* Run through open doors */
-extern int delay_spd;                   /* 1-10 for delays */
+extern int find_ignore_doors;	/* Run through open doors */
+extern int delay_spd;			/* 1-10 for delays */
 extern int hitpoint_warn;		/* Low hitpoint warning */
-extern int peek;                        /* should we display additional msgs */
-extern int carry_query_flag;            /* ask whether to pick something up */
-extern int is_home;                     /* are we in our home? */
+extern int peek;				/* should we display additional msgs */
+extern int carry_query_flag;	/* ask whether to pick something up */
+extern int is_home;				/* are we in our home? */
 extern int in_store_flag;		/* Don't redisplay light in stores -DGK */
-extern int plain_descriptions;          /* don't add color to any obj -CWS */
-extern int no_haggle_flag;              /* does the player have to haggle? -CWS */
+extern int plain_descriptions;	/* don't add color to any obj -CWS */
+extern int no_haggle_flag;		/* does the player have to haggle? -CWS */
 extern int quick_messages;		/* do quick messages -CWS */
-extern int equippy_chars;	        /* do equipment characters -CWS */
+extern int equippy_chars;		/* do equipment characters -CWS */
+extern int coin_type;			/* remember Creeping _xxx_ coin type -CWS */
+extern int opening_chest;		/* do not generate another chest -CWS */
 
 /* Unique artifact weapon flags */
-extern int GROND, RINGIL, AEGLOS, ARUNRUTH, MORMEGIL, ANGRIST, GURTHANG,
+extern int32 GROND, RINGIL, AEGLOS, ARUNRUTH, MORMEGIL, ANGRIST, GURTHANG,
   CALRIS, ANDURIL, STING, ORCRIST, GLAMDRING, DURIN, AULE, THUNDERFIST,
   BLOODSPIKE, DOOMCALLER, NARTHANC, NIMTHANC, DETHANC, GILETTAR, RILIA,
   BELANGIL, BALLI, LOTHARANG, FIRESTAR, ERIRIL, CUBRAGOL, BARD, COLLUIN,
@@ -72,7 +75,7 @@ extern int GROND, RINGIL, AEGLOS, ARUNRUTH, MORMEGIL, ANGRIST, GURTHANG,
   EONWE, THEODEN, ULMO, OSONDIR, TURMIL, TIL, DEATHWREAKER, AVAVIR, TARATOL;
 
 /* Unique artifact armour flags */
-extern int DOR_LOMIN, NENYA, NARYA, VILYA, BELEGENNON, FEANOR, ISILDUR,
+extern int32 DOR_LOMIN, NENYA, NARYA, VILYA, BELEGENNON, FEANOR, ISILDUR,
 SOULKEEPER, FINGOLFIN, ANARION, POWER, PHIAL, BELEG, DAL, PAURHACH,
 PAURNIMMEN, PAURAEGEN, PAURNEN, CAMMITHRIM, CAMBELEG, INGWE, CARLAMMAS,
 HOLHENNETH, AEGLIN, CAMLOST, NIMLOTH, NAR, BERUTHIEL, GORLIM, ELENDIL,
@@ -86,53 +89,53 @@ extern int quests[MAX_QUESTS];
 
 /* global flags */
 extern int unfelt;
-extern int in_store_flag;       /* flag so equippy chars work right -DGK */
-extern int good_item_flag;      /* True if an artifact has been created... */
+extern int in_store_flag;		/* flag so equippy chars work right -DGK */
+extern int good_item_flag;		/* True if an artifact has been created... */
 extern int LOAD;
-extern int new_level_flag;	/* Next level when true  */
-extern int teleport_flag;	/* Handle teleport traps  */
-extern int eof_flag;		/* Used to handle eof/HANGUP */
-extern int player_light;        /* Player carrying light */
-extern int light_rad;           /* Light radius */
+extern int new_level_flag;		/* Next level when true  */
+extern int teleport_flag;		/* Handle teleport traps  */
+extern int eof_flag;			/* Used to handle eof/HANGUP */
+extern int player_light;		/* Player carrying light */
+extern int light_rad,old_rad;           /* Light radius */
 extern int find_flag;        	/* Used in MORIA	      */
-extern int free_turn_flag;	/* Used in MORIA	      */
-extern int weapon_heavy;	/* Flag if the weapon too heavy -CJS- */
-extern int pack_heavy;		/* Flag if the pack too heavy -CJS- */
-extern char doing_inven;	/* Track inventory commands */
-extern int screen_change;	/* Screen changes (used in inven_commands) */
+extern int free_turn_flag;		/* Used in MORIA	      */
+extern int weapon_heavy;		/* Flag if the weapon too heavy -CJS- */
+extern int pack_heavy;			/* Flag if the pack too heavy -CJS- */
+extern char doing_inven;		/* Track inventory commands */
+extern int screen_change;		/* Screen changes (used in inven_commands) */
 extern int be_nasty;
-extern int monster_is_afraid;	        /* redo monster fear messages -CWS */
+extern int monster_is_afraid;	/* redo monster fear messages -CWS */
 
-extern int character_generated;	 /* don't save score until char gen finished */
-extern int character_saved;	 /* prevents save on kill after save_char() */
-extern int feeling;              /* level feeling */
-extern int highscore_fd;	 /* High score file descriptor */
-extern int command_count;	 /* Repetition of commands. -CJS- */
-extern int default_dir;		 /* Use last direction in repeated commands */
-extern int16 noscore;		 /* Don't score this game. -CJS- */
-extern int32u randes_seed;       /* For encoding colors */
-extern int32u town_seed;	 /* Seed for town generation */
-extern char *old_state;          /* state array initialized by time -CWS */
-extern char *dummy_state;        /* dummy state array so that town/colors look
-                                  * the same -CWS */
+extern int character_generated;	/* don't save score until char gen finished */
+extern int character_saved;		/* prevents save on kill after save_char() */
+extern int feeling;				/* level feeling */
+extern int highscore_fd;		/* High score file descriptor */
+extern int command_count;		/* Repetition of commands. -CJS- */
+extern int default_dir;			/* Use last direction in repeated commands */
+extern int16 noscore;			/* Don't score this game. -CJS- */
+extern int32u randes_seed;		/* For encoding colors */
+extern int32u town_seed;		/* Seed for town generation */
+extern char *old_state;			/* state array initialized by time -CWS */
+extern char *dummy_state;		/* dummy state array so that town/colors look
+                                 * the same -CWS */
 
 extern int16 dun_level;         /* Cur dungeon level   */
-extern int16 object_level;    /* used to generate out-of-depth objects -CWS */
-extern int16 missile_ctr;	 /* Counter for missiles */
-extern int msg_flag;	         /* Set with first msg  */
+extern int16 object_level;		/* used to generate objects -CWS */
+extern int16 missile_ctr;		/* Counter for missiles */
+extern int msg_flag;			/* Set with first msg  */
 extern vtype old_msg[MAX_SAVE_MSG];	/* Last messages -CJS- */
 extern int16 last_msg;			/* Where in the array is the last */
-extern int death;	/* True if died	      */
-extern int32 turn;	/* Cur trun of game    */
-extern int32 old_turn;	/* last turn feeling was felt */
-extern int wizard;	/* Wizard flag	      */
+extern int death;				/* True if died	      */
+extern int32 turn;				/* Cur turn of game    */
+extern int32 old_turn;			/* last turn feeling was felt */
+extern int wizard;				/* Wizard flag	      */
 extern int to_be_wizard;
-extern int16 panic_save; /* this is true if playing from a panic save */
+extern int16 panic_save;		/* this is true if playing from a panic save */
 
 extern int wait_for_more;
 
 extern char days[7][29];
-extern int closing_flag;	/* Used for closing   */
+extern int closing_flag;		/* Used for closing   */
 
 extern int16 cur_height, cur_width;	/* Cur dungeon size    */
 /*  Following are calculated from max dungeon sizes		*/
@@ -174,7 +177,7 @@ extern int16 char_row;
 extern int16 char_col;
 
 #if 0 /* not used? */
-extern char *dsp_race[MAX_RACES];	/* Short strings for races. -CJS- */
+extern char *dsp_race[MAX_RACES]; /* Short strings for races. -CJS- */
 #endif
 
 extern int8u rgold_adj[MAX_RACES][MAX_RACES];
@@ -191,13 +194,13 @@ extern spell_type magic_spell[MAX_CLASS-1][63];
 extern const char *spell_names[127];
 extern int32u spell_learned;	/* Bit field for spells learnt -CJS- */
 extern int32u spell_learned2;	/* Bit field for spells learnt -CJS- */
-extern int32u spell_worked;	/* Bit field for spells tried -CJS- */
+extern int32u spell_worked;		/* Bit field for spells tried -CJS- */
 extern int32u spell_worked2;	/* Bit field for spells tried -CJS- */
 extern int32u spell_forgotten;	/* Bit field for spells forgotten -JEW- */
 extern int32u spell_forgotten2;	/* Bit field for spells forgotten -JEW- */
 extern int8u spell_order[64];	/* remember order that spells are learned in */
-extern int32u spellmasks[MAX_CLASS][2]; /* used to check if player knows all
-					   spells knowable to him -CFT */
+extern int32u spellmasks[MAX_CLASS][2];
+/* used to check if player knows all spells knowable to him -CFT */
 extern int16u player_init[MAX_CLASS][5];
 extern int16 total_winner;
 
@@ -229,10 +232,10 @@ extern inven_type t_list[MAX_TALLOC];
 extern inven_type inventory[INVEN_ARRAY_SIZE];
 extern const char *special_names[SN_ARRAY_SIZE];
 extern int16 sorted_objects[MAX_DUNGEON_OBJ];
-extern int16 inven_ctr;		/* Total different obj's	*/
-extern int16 inven_weight;	/* Cur carried weight	*/
-extern int16 equip_ctr;	/* Cur equipment ctr	*/
-extern int16 tcptr;	/* Cur treasure heap ptr	*/
+extern int16 inven_ctr;			/* Total different obj's	*/
+extern int16 inven_weight;		/* Cur carried weight	*/
+extern int16 equip_ctr;			/* Cur equipment ctr	*/
+extern int16 tcptr;				/* Cur treasure heap ptr	*/
 
 /* Following are creature arrays and variables			*/
 #ifdef MACGAME
@@ -249,9 +252,9 @@ extern recall_type *c_recall;
 #else
 extern recall_type c_recall[MAX_CREATURES];	/* Monster memories. -CJS- */
 #endif
-extern monster_type blank_monster;	/* Blank monster values	*/
-extern int16 mfptr;	/* Cur free monster ptr	*/
-extern int16 mon_tot_mult;	/* # of repro's of creature	*/
+extern monster_type blank_monster; /* Blank monster values	*/
+extern int16 mfptr;				   /* Cur free monster ptr	*/
+extern int16 mon_tot_mult;		   /* # of repro's of creature	*/
 
 /* Following are arrays for descriptive pieces			*/
 #ifdef MACGAME
@@ -280,7 +283,7 @@ extern int16u normal_table[NORMAL_TABLE_SIZE];
 /* Since these get modified, macrsrc.c must be able to access them */
 /* Otherwise, game cannot be made restartable */
 /* dungeon.c */
-extern char last_command;  /* Memory of previous command. */
+extern char last_command;		/* Memory of previous command. */
 /* moria1.c */
 /* Track if temporary light about player.  */
 extern int light_flag;
@@ -291,10 +294,33 @@ extern int	ansi, saveprompt;
 extern char	moriatop[], moriasav[];
 #endif
 
+
+/* If you use NEW_FILEPATHS, we need these externs; if you use OLD_FILEPATHS */
+/* these are #define'd to something, so they aren't variables.         [cjh] */
+#ifdef NEW_FILEPATHS
+extern char *ANGBAND_TST;		/* was LIBDIR(test)					*/
+extern char *ANGBAND_HOU;		/* was LIBDIR(files/hours)			*/
+extern char *ANGBAND_MOR;		/* was LIBDIR(files/news)			*/
+extern char *ANGBAND_TOP;		/* was LIBDIR(files/newscores)		*/
+extern char *ANGBAND_BONES;		/* was LIBDIR(bones)				*/
+extern char *ANGBAND_HELP;		/* was LIBDIR(files/roglcmds.hlp)	*/
+extern char *ANGBAND_ORIG_HELP;	/* was LIBDIR(files/origcmds.hlp)	*/
+extern char *ANGBAND_WIZ_HELP;	/* was LIBDIR(files/rwizcmds.hlp)	*/
+extern char *ANGBAND_OWIZ_HELP;	/* was LIBDIR(files/owizcmds.hlp)	*/
+extern char *ANGBAND_WELCOME;	/* was LIBDIR(files/welcome.hlp)	*/
+extern char *ANGBAND_LOG;		/* was LIBDIR(files/ANGBAND.log)	*/
+extern char *ANGBAND_VER;		/* was LIBDIR(files/version.hlp)	*/
+extern char *ANGBAND_LOAD;		/* was LIBDIR(files/loadcheck)		*/
+extern char *ANGBAND_WIZ;		/* was LIBDIR(files/wizards)		*/
+extern char *ANGBAND_SAV;		/* was LIBDIR(save)					*/
+#endif /* NEW_FILEPATHS */
+
+
 /* function return values */
 /* only extern functions declared here, static functions declared inside
    the file that defines them */
 #ifdef __STDC__
+
 /* create.c */
 void create_character(void);
 
@@ -355,6 +381,9 @@ int file_character(void)
 #else
 int file_character(char *);
 #endif
+#ifdef NEW_FILEPATHS
+void get_file_paths( void );
+#endif
 
 /* generate.c */
 void generate_cave(void);
@@ -400,7 +429,7 @@ void cast(void);
 int main(int, char **);
 
 /* misc1.c */
-void init_seeds(int32u);
+void init_seeds();
 void set_seed(int32u);
 void reset_seed(void);
 int check_time(void);
@@ -538,7 +567,8 @@ void prt_stun(void);
 void special_random_object(int, int, int);
 void cut_player(int);
 void stun_player(int);
-extern void prt_equippy_chars(void);
+void prt_equippy_chars(void);
+void get_coin_type(creature_type *);
 
 /* monsters.c */
 
@@ -579,6 +609,7 @@ void fire_dam(int, const char *);
 void cold_dam(int, const char *);
 void light_dam(int, const char *);
 void acid_dam(int, const char *);
+void darken_player(int, int);
 
 /* moria2.c */
 int cast_spell(const char * ,int, int *, int *);
@@ -636,9 +667,9 @@ int roff_recall(int);
 
 /* rnd.c is unused now -CWS */
 /* random.c */
-#ifndef linux
+#if !(defined(linux) || defined(__osf__))
 long random(void);
-#ifndef __MINT__
+#if !(defined(__MINT__) || defined(__386BSD__))
 void srandom(int);
 #endif
 char *initstate(unsigned int, char *, int);
@@ -682,6 +713,7 @@ int weaponsmith(int);
 int temple(int);
 int alchemist(int);
 int magic_shop(int);
+
 #ifdef MAC
 int store_buy(int, int);
 #endif
@@ -718,8 +750,8 @@ void frost_line(int, int, int, int);
 void starlite(int, int);
 int disarm_all(int, int, int);
 void get_flags(int, int32u *, int32u *, int (**)());
-void fire_bolt(int, int, int, int, int, const char *);
-void fire_ball(int, int, int, int, int, int, const char *);
+void fire_bolt(int, int, int, int, int);
+void fire_ball(int, int, int, int, int, int);
 void breath(int, int, int, int, char *, int);
 int recharge(int);
 int hp_monster(int, int, int, int);
@@ -763,7 +795,7 @@ int slow_poison(void);
 void bless(int);
 void detect_inv2(int);
 void destroy_area(int, int);
-int enchant(int16 *, int);
+int enchant(inven_type *, int, int8u);
 void elemental_brand(void);
 int remove_curse(void);
 int restore_level(void);
@@ -781,6 +813,7 @@ int remove_all_curse(void);
 void darken_room(int, int);
 void lite_spot(int, int);
 const char *pain_message(int, int);
+void line_spell(int, int, int, int, int);
 
 /* staffs.c */
 void use(void);
@@ -819,6 +852,14 @@ FILE *my_tfopen(const char *, const char *);
 int my_topen(const char *, int, int);
 #endif
 
+/* util.c */
+#ifdef NEEDS_STRICMP
+int my_stricmp(const char *, const char *);
+#endif
+#ifdef NEEDS_USLEEP
+int microsleep(unsigned long);
+#endif
+
 /* variable.c */
 
 /* wands.c */
@@ -891,6 +932,9 @@ void read_times();
 void helpfile();
 void print_objects();
 int file_character();
+#ifdef NEW_FILEPATHS
+void get_file_paths();
+#endif
 
 /* generate.c */
 void generate_cave();
@@ -1056,6 +1100,7 @@ void special_random_object();
 void cut_player();
 void stun_player();
 extern void prt_equippy_chars();
+void get_coin_type();
 
 /* monsters.c */
 
@@ -1101,6 +1146,7 @@ void cold_dam();
 void light_dam();
 void acid_dam();
 void lite_spot();
+void darken_player();
 
 /* moria2.c */
 int cast_spell();
@@ -1120,9 +1166,9 @@ void disarm_trap();
 void look();
 void throw_object();
 void bash();
-void target(); /* target fns stolen from Morgul -CFT */
-int at_target(); /* target fns stolen from Morgul -CFT */
-void mmove2(); /* target fns stolen from Morgul -CFT */
+void target();					/* target fns stolen from Morgul -CFT */
+int at_target();				/* target fns stolen from Morgul -CFT */
+void mmove2();					/* target fns stolen from Morgul -CFT */
 
 #ifdef MSDOS
 /* ms_misc.c */
@@ -1157,10 +1203,12 @@ int roff_recall();
 
 /* rnd.c is unused now -CWS */
 /* random.c */
+#if !(defined(linux) || defined(__osf__))
 long random();
 void srandom();
 char *initstate();
 char *setstate();
+#endif
 
 /* save.c */
 int save_char();
@@ -1182,6 +1230,10 @@ int set_lightning_destroy();
 int set_null();
 int set_acid_destroy();
 int set_fire_destroy();
+int set_plasma_destroy();
+int set_meteor_destroy();
+int set_holy_destroy();
+int set_mana_destroy();
 int general_store();
 int armory();
 int weaponsmith();
@@ -1271,7 +1323,8 @@ int enchant();
 int remove_curse();
 int restore_level();
 void self_knowledge();
-char *pain_message();
+char *pain_message()
+void line_spell();
 
 /* staffs.c */
 void use();
@@ -1307,13 +1360,22 @@ int system_cmd();
 void user_name();
 int tilde();
 /* only declare this if stdio.h has been previously included, which will
- be true if stdin is defined */
+ * be true if stdin is defined
+ */
 #ifdef stdin
 FILE *my_tfopen();
 #endif
 int my_topen();
 #endif
 
+/* util.c */
+#ifdef NEEDS_STRICMP
+int my_stricmp();
+#endif
+#ifdef NEEDS_USLEEP
+int microsleep();
+#endif
+
 /* variable.c */
 
 /* wands.c */
