@@ -20,6 +20,10 @@
 #include "types.h"
 #include "externs.h"
 
+#ifdef ibm032
+#include <ctype.h>
+#endif
+
 #ifdef MSDOS
 extern int          errno;
 
@@ -50,11 +54,196 @@ char               *strcat();
 
 #ifndef VMS
 #if defined(ultrix) || defined(USG)
-void                exit();
+void exit();
 
 #endif
 #endif
 
+
+/* This is done first in main.c, so I'll rudely drop it into the front
+ * of files.c...  If NEW_FILEPATHS is defined, we'll look for the ANGBAND_PATH
+ * environment variable, and then look for the files in there.  This is
+ * much nicer than having explicit paths, and should help us make things
+ * more portable.  Now, if only someone would graft on the NetHack display
+ * code...
+ *
+ * This is rather inelegant code; no checks are made for malloc() or
+ * realloc() failures.  If you malloc/realloc are broken, you're in
+ * trouble, and your compiler vendor needs a good swift kick in the
+ * forehead. [cjh]
+ */
+#ifdef NEW_FILEPATHS
+char *ANGBAND_TST;		/* was LIBDIR(test)			*/
+char *ANGBAND_HOU;		/* was LIBDIR(files/hours)		*/
+char *ANGBAND_MOR;		/* was LIBDIR(files/news)		*/
+char *ANGBAND_TOP;		/* was LIBDIR(files/newscores)		*/
+char *ANGBAND_BONES;		/* was LIBDIR(bones)			*/
+char *ANGBAND_HELP;		/* was LIBDIR(files/roglcmds.hlp)	*/
+char *ANGBAND_ORIG_HELP;	/* was LIBDIR(files/origcmds.hlp)	*/
+char *ANGBAND_WIZ_HELP;		/* was LIBDIR(files/rwizcmds.hlp)	*/
+char *ANGBAND_OWIZ_HELP;	/* was LIBDIR(files/owizcmds.hlp)	*/
+char *ANGBAND_WELCOME;		/* was LIBDIR(files/welcome.hlp)	*/
+char *ANGBAND_LOG;		/* was LIBDIR(files/ANGBAND.log)	*/
+char *ANGBAND_VER;		/* was LIBDIR(files/version.hlp)	*/
+char *ANGBAND_LOAD;		/* was LIBDIR(files/loadcheck)		*/
+char *ANGBAND_WIZ;		/* was LIBDIR(files/wizards)		*/
+char *ANGBAND_SAV;		/* was LIBDIR(save)			*/
+
+void get_file_paths()
+{
+#ifndef MAXPATHLEN
+#define BOZO_MAXPATHLEN
+#define MAXPATHLEN 512
+#endif
+
+    char *angband_path;
+
+/* Find the path to our files...  if the ANGBAND_PATH environment var
+ * isn't set, use DEFAULT_PATH to look for the files.  If your system
+ * can't do environment variables, you'll have to kludge this.  [cjh]
+ */
+
+    angband_path = getenv( "ANGBAND_PATH" );
+    if (angband_path == NULL) {
+
+#if 0 /* I don't think this is appropriate, particularly since this may
+       * well be set by a system-wide games administrator.  -CWS */
+
+       fprintf(stderr, "Warning: ANGBAND_PATH not set!\n" );
+       fprintf(stderr, "Warning: Using %s for ANGBAND_PATH.\n", DEFAULT_PATH );
+#endif
+	angband_path = (char *)malloc( strlen( DEFAULT_PATH ) + 1 );
+	strcpy( angband_path, DEFAULT_PATH );
+    }
+
+    ANGBAND_TST = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_TST, angband_path );
+    strcat( ANGBAND_TST, PATH_SEP );
+    strcat( ANGBAND_TST, "test" );
+    ANGBAND_TST = (char *)realloc( ANGBAND_TST, strlen( ANGBAND_TST ) + 1 );
+
+    ANGBAND_HOU = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_HOU, angband_path );
+    strcat( ANGBAND_HOU, PATH_SEP );
+    strcat( ANGBAND_HOU, "files" );
+    strcat( ANGBAND_HOU, PATH_SEP );
+    strcat( ANGBAND_HOU, "hours" );
+    ANGBAND_HOU = (char *)realloc( ANGBAND_HOU, strlen( ANGBAND_HOU ) + 1 );
+
+    ANGBAND_MOR = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_MOR, angband_path );
+    strcat( ANGBAND_MOR, PATH_SEP );
+    strcat( ANGBAND_MOR, "files" );
+    strcat( ANGBAND_MOR, PATH_SEP );
+    strcat( ANGBAND_MOR, "news" );
+    ANGBAND_MOR = (char *)realloc( ANGBAND_MOR, strlen( ANGBAND_MOR ) + 1 );
+
+    ANGBAND_TOP = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_TOP, angband_path );
+    strcat( ANGBAND_TOP, PATH_SEP );
+    strcat( ANGBAND_TOP, "files" );
+    strcat( ANGBAND_TOP, PATH_SEP );
+    strcat( ANGBAND_TOP, "newscores" );
+    ANGBAND_TOP = (char *)realloc( ANGBAND_TOP, strlen( ANGBAND_TOP ) + 1 );
+
+    ANGBAND_BONES = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_BONES, angband_path );
+    strcat( ANGBAND_BONES, PATH_SEP );
+    strcat( ANGBAND_BONES, "bones" );
+    ANGBAND_BONES = (char *)realloc( ANGBAND_BONES, strlen( ANGBAND_BONES ) + 1 );
+
+    ANGBAND_HELP = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_HELP, angband_path );
+    strcat( ANGBAND_HELP, PATH_SEP );
+    strcat( ANGBAND_HELP, "files" );
+    strcat( ANGBAND_HELP, PATH_SEP );
+    strcat( ANGBAND_HELP, "roglcmds.hlp" );
+    ANGBAND_HELP = (char *)realloc( ANGBAND_HELP, strlen( ANGBAND_HELP ) + 1 );
+
+    ANGBAND_ORIG_HELP = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_ORIG_HELP, angband_path );
+    strcat( ANGBAND_ORIG_HELP, PATH_SEP );
+    strcat( ANGBAND_ORIG_HELP, "files" );
+    strcat( ANGBAND_ORIG_HELP, PATH_SEP );
+    strcat( ANGBAND_ORIG_HELP, "origcmds.hlp" );
+    ANGBAND_ORIG_HELP = (char *)realloc(ANGBAND_ORIG_HELP,
+					strlen( ANGBAND_ORIG_HELP ) + 1 );
+
+    ANGBAND_WIZ_HELP = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_WIZ_HELP, angband_path );
+    strcat( ANGBAND_WIZ_HELP, PATH_SEP );
+    strcat( ANGBAND_WIZ_HELP, "files" );
+    strcat( ANGBAND_WIZ_HELP, PATH_SEP );
+    strcat( ANGBAND_WIZ_HELP, "rwizcmds.hlp" );
+    ANGBAND_WIZ_HELP = (char *)realloc(ANGBAND_WIZ_HELP,
+				       strlen( ANGBAND_WIZ_HELP ) + 1 );
+
+    ANGBAND_OWIZ_HELP = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_OWIZ_HELP, angband_path );
+    strcat( ANGBAND_OWIZ_HELP, PATH_SEP );
+    strcat( ANGBAND_OWIZ_HELP, "files" );
+    strcat( ANGBAND_OWIZ_HELP, PATH_SEP );
+    strcat( ANGBAND_OWIZ_HELP, "owizcmds.hlp" );
+    ANGBAND_OWIZ_HELP = (char *)realloc(ANGBAND_OWIZ_HELP,
+					strlen( ANGBAND_OWIZ_HELP ) + 1 );
+
+    ANGBAND_WELCOME = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_WELCOME, angband_path );
+    strcat( ANGBAND_WELCOME, PATH_SEP );
+    strcat( ANGBAND_WELCOME, "files" );
+    strcat( ANGBAND_WELCOME, PATH_SEP );
+    strcat( ANGBAND_WELCOME, "welcome.hlp" );
+    ANGBAND_WELCOME = (char *)realloc( ANGBAND_WELCOME, strlen( ANGBAND_WELCOME ) + 1 );
+
+    ANGBAND_LOG = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_LOG, angband_path );
+    strcat( ANGBAND_LOG, PATH_SEP );
+    strcat( ANGBAND_LOG, "files" );
+    strcat( ANGBAND_LOG, PATH_SEP );
+    strcat( ANGBAND_LOG, "ANGBAND.log" );
+    ANGBAND_LOG = (char *)realloc( ANGBAND_LOG, strlen( ANGBAND_LOG ) + 1 );
+
+    ANGBAND_VER = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_VER, angband_path );
+    strcat( ANGBAND_VER, PATH_SEP );
+    strcat( ANGBAND_VER, "files" );
+    strcat( ANGBAND_VER, PATH_SEP );
+    strcat( ANGBAND_VER, "version.hlp" );
+    ANGBAND_VER = (char *)realloc( ANGBAND_VER, strlen( ANGBAND_VER ) + 1 );
+
+    ANGBAND_LOAD = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_LOAD, angband_path );
+    strcat( ANGBAND_LOAD, PATH_SEP );
+    strcat( ANGBAND_LOAD, "files" );
+    strcat( ANGBAND_LOAD, PATH_SEP );
+    strcat( ANGBAND_LOAD, "loadcheck" );
+    ANGBAND_LOAD = (char *)realloc( ANGBAND_LOAD, strlen( ANGBAND_LOAD ) + 1 );
+
+    ANGBAND_WIZ = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_WIZ, angband_path );
+    strcat( ANGBAND_WIZ, PATH_SEP );
+    strcat( ANGBAND_WIZ, "files" );
+    strcat( ANGBAND_WIZ, PATH_SEP );
+    strcat( ANGBAND_WIZ, "wizards" );
+    ANGBAND_WIZ = (char *)realloc( ANGBAND_WIZ, strlen( ANGBAND_WIZ ) + 1 );
+
+    ANGBAND_SAV = (char *)malloc( MAXPATHLEN );
+    strcpy( ANGBAND_SAV, angband_path );
+    strcat( ANGBAND_SAV, PATH_SEP );
+    strcat( ANGBAND_SAV, "save" );
+    ANGBAND_SAV = (char *)realloc( ANGBAND_SAV, strlen( ANGBAND_SAV ) + 1 );
+
+    return;
+}
+
+#ifdef BOZO_MAXPATHLEN
+#undef BOZO_MAXPATHLEN
+#undef MAXPATHLEN
+#endif /* BOZO_MAXPATHLEN */
+
+#endif /* NEW_FILEPATHS */
+
+
 /* Not touched for Mac port */
 /*
  * init_scorefile Open the score file while we still have the setuid
@@ -83,11 +272,11 @@ init_scorefile()
 void 
 read_times()
 {
-    register int        i;
-    vtype               in_line;
-    FILE               *file1;
+    register int i;
+    vtype        in_line;
+    FILE        *file1;
 
-#ifdef ANGBAND_HOU
+#ifdef CHECKHOURS
 /* Attempt to read hours.dat.	 If it does not exist,	   */
 /* inform the user so he can tell the wizard about it	 */
     if ((file1 = my_tfopen(ANGBAND_HOU, "r")) != NULL) {
@@ -115,7 +304,6 @@ read_times()
 	exit(1);
     }
 
-#ifdef CHECKHOURS
 /* Check the hours, if closed	then exit. */
     if (!check_time()) {
 	if ((file1 = my_tfopen(ANGBAND_HOU, "r")) != NULL) {
@@ -127,7 +315,7 @@ read_times()
 	}
 	exit_game();
     }
-#endif				   /* CHECKHOURS */
+#endif				   /* CHECK_HOURS */
 
 /* Print the introduction message, news, etc.		 */
     if ((file1 = my_tfopen(ANGBAND_MOR, "r")) != NULL) {
@@ -137,7 +325,6 @@ read_times()
 	pause_line(23);
 	(void)fclose(file1);
     }
-#endif
 }
 
 /*
@@ -145,12 +332,12 @@ read_times()
  */
 void 
 helpfile(filename)
-    const char         *filename;
+const char *filename;
 {
-    bigvtype            tmp_str;
-    FILE               *file;
-    char                input;
-    int                 i;
+    bigvtype tmp_str;
+    FILE    *file;
+    char     input;
+    int      i;
 
     file = my_tfopen(filename, "r");
     if (file == NULL) {
@@ -181,11 +368,11 @@ helpfile(filename)
 void 
 print_objects()
 {
-    register int        i;
-    int                 nobj, j, level;
-    vtype               filename1;
-    bigvtype            tmp_str;
-    register FILE      *file1;
+    register int         i;
+    int                  nobj, j, level;
+    vtype                filename1;
+    bigvtype             tmp_str;
+    register FILE       *file1;
     register inven_type *i_ptr;
 
     prt("Produce objects on what level?: ", 0, 0);
@@ -363,18 +550,18 @@ print_objects()
 /* Print the character to a file or device		-RAK-	 */
 int 
 file_character(filename1)
-    char               *filename1;
+char *filename1;
 {
-    register int        i;
-    int                 j, xbth, xbthb, xfos, xsrh, xstl, xdis, xsave, xdev;
-    vtype               xinfra;
-    int                 fd;
-    register FILE      *file1;
-    bigvtype            prt2;
+    register int          i;
+    int                   j, xbth, xbthb, xfos, xsrh, xstl, xdis, xsave, xdev;
+    vtype                 xinfra;
+    int                   fd;
+    register FILE        *file1;
+    bigvtype              prt2;
     register struct misc *p_ptr;
-    register inven_type *i_ptr;
-    vtype               out_val, prt1;
-    const char          *p, *colon, *blank;
+    register inven_type  *i_ptr;
+    vtype                 out_val, prt1;
+    const char           *p, *colon, *blank;
 
     fd = my_topen(filename1, O_WRONLY | O_CREAT | O_EXCL, 0644);
     if (fd < 0 && errno == EEXIST) {
@@ -429,20 +616,20 @@ file_character(filename1)
 	(void)fprintf(file1, "%7sLevel      :%9d", blank, (int)py.misc.lev);
 	(void)fprintf(file1, "   Max Hit Points : %6d\n", py.misc.mhp);
 	(void)fprintf(file1, " + To Damage : %6d", py.misc.dis_td);
-	(void)fprintf(file1, "%7sExperience :%9ld", blank, py.misc.exp);
+	(void)fprintf(file1, "%7sExperience :%9ld", blank, (long)py.misc.exp);
 	(void)fprintf(file1, "   Cur Hit Points : %6d\n", py.misc.chp);
 	(void)fprintf(file1, " + To AC     : %6d", py.misc.dis_tac);
-	(void)fprintf(file1, "%7sMax Exp    :%9ld", blank, py.misc.max_exp);
+	(void)fprintf(file1, "%7sMax Exp    :%9ld", blank, (long)py.misc.max_exp);
 	(void)fprintf(file1, "   Max Mana%8s %6d\n", colon, py.misc.mana);
 	(void)fprintf(file1, "   Total AC  : %6d", py.misc.dis_ac);
 	if (py.misc.lev >= MAX_PLAYER_LEVEL)
 	    (void)fprintf(file1, "%7sExp to Adv.:%9s", blank, "****");
 	else
 	    (void)fprintf(file1, "%7sExp to Adv.:%9ld", blank,
-			  (int32) (player_exp[py.misc.lev - 1] *
+			  (long) (player_exp[py.misc.lev - 1] *
 				   py.misc.expfact / 100));
 	(void)fprintf(file1, "   Cur Mana%8s %6d\n", colon, py.misc.cmana);
-	(void)fprintf(file1, "%28sGold%8s%9ld\n", blank, colon, py.misc.au);
+	(void)fprintf(file1, "%28sGold%8s%9ld\n", blank, colon, (long)py.misc.au);
 
 	p_ptr = &py.misc;
 	xbth = p_ptr->bth + p_ptr->ptohit * BTH_PLUS_ADJ
