@@ -38,33 +38,36 @@
 #include <stat.h>		/* chmod() */
 #endif
 
-static int          sv_write();
-static void         wr_byte();
-static void         wr_short();
-static void         wr_long();
-static void         wr_bytes();
-static void         wr_string();
-static void         wr_shorts();
-static void         wr_item();
-static void         wr_monster();
-static void         rd_byte();
-static void         rd_short();
-static void         rd_long();
-static void         rd_bytes();
-static void         rd_string();
-static void         rd_shorts();
-static void         rd_item();
-static void         rd_monster();
+/* Lets do all prototypes correctly.... -CWS */
+#ifndef NO_LINT_ARGS
+static int sv_write();
+static void wr_byte();
+static void wr_short();
+static void wr_long();
+static void wr_bytes();
+static void wr_string();
+static void wr_shorts();
+static void wr_item();
+static void wr_monster();
+static void rd_byte();
+static void rd_short();
+static void rd_long();
+static void rd_bytes();
+static void rd_string();
+static void rd_shorts();
+static void rd_item();
+static void rd_monster();
+#endif
 
 #if !defined(ATARIST_MWC)
 #ifdef MAC
 #include <time.h>
 #else
-long                time();
+long time();
 
 #endif
 #else
-char               *malloc();
+char *malloc();
 
 #endif
 
@@ -80,6 +83,7 @@ static FILE        *fileptr;
 static int8u        xor_byte;
 static int          from_savefile; /* can overwrite old savefile when save */
 static int32u       start_time;	   /* time that play started */
+static int8u        version_maj, version_min, patch_level;
 
 /*
  * This save package was brought to by			-JWT- and
@@ -89,12 +93,12 @@ static int32u       start_time;	   /* time that play started */
 /* and completely rewritten again! for portability by -JEW- */
 
 
-static char        *
+static char *
 basename(a)
-    char               *a;
+char *a;
 {
-    char               *b;
-    char               *strrchr();
+    char *b;
+    char *strrchr();
 
     if ((b = strrchr(a, (int)'/')) == (char *)0)
 	return a;
@@ -103,7 +107,7 @@ basename(a)
 
 static void 
 wr_unique(item)
-    register struct unique_mon *item;
+register struct unique_mon *item;
 {
     wr_long((int32u) item->exist);
     wr_long((int32u) item->dead);
@@ -111,7 +115,7 @@ wr_unique(item)
 
 static void 
 rd_unique(item)
-    register struct unique_mon *item;
+register struct unique_mon *item;
 {
     rd_long((int32u *) & item->exist);
     rd_long((int32u *) & item->dead);
@@ -125,20 +129,19 @@ sv_write()
     register int        i, j;
     int                 count;
     int8u               char_tmp, prev_char;
-    register cave_type *c_ptr;
+    register cave_type   *c_ptr;
     register recall_type *r_ptr;
-    struct stats       *s_ptr;
+    struct stats         *s_ptr;
 
 #ifdef MSDOS
-    inven_type         *t_ptr;
+    inven_type           *t_ptr;
 
 #endif
     register struct flags *f_ptr;
-    store_type         *st_ptr;
-    struct misc        *m_ptr;
+    store_type  *st_ptr;
+    struct misc *m_ptr;
 
-/*
- * clear the death flag when creating a HANGUP save file, so that player can
+/* clear the death flag when creating a HANGUP save file, so that player can
  * see tombstone when restart 
  */
 
@@ -330,11 +333,13 @@ sv_write()
 	    wr_bytes(r_ptr->r_attacks, MAX_MON_NATTACK);
 	}
     }
-    wr_short((int16u) 0xFFFF);	   /* sentinel to indicate no more monster
-				    * info */
+    wr_short((int16u) 0xFFFF);	   /* sentinel to indicate no more monster info */
 
     wr_short((int16u) log_index);
     wr_long(l);
+    wr_long(l);	/* added some duplicates, for future flags expansion -CWS */
+    wr_long(l);
+    wr_long(l);
 
     m_ptr = &py.misc;
     wr_string(m_ptr->name);
@@ -453,9 +458,11 @@ sv_write()
     wr_byte(f_ptr->nexus_resist);
     wr_byte(f_ptr->blindness_resist);
     wr_byte(f_ptr->nether_resist);
+    wr_byte(f_ptr->fear_resist); /* added -CWS */
 
     wr_short((int16u) missile_ctr);
     wr_long((int32u) turn);
+    wr_long((int32u) old_turn);	/* added -CWS */
     wr_short((int16u) inven_ctr);
     for (i = 0; i < inven_ctr; i++)
 	wr_item(&inventory[i]);
@@ -501,8 +508,8 @@ sv_write()
 
 /* save the current time in the savefile */
     l = time((long *)0);
-/*
- * if (l < start_time) { someone is messing with the clock!, assume that we
+
+/* if (l < start_time) { someone is messing with the clock!, assume that we
  * have been playing for 1 day l = start_time + 86400L; } 
  */
     wr_long(l);
@@ -510,8 +517,7 @@ sv_write()
 /* starting with 5.2, put died_from string in savefile */
     wr_string(died_from);
 
-/*
- * only level specific info follows, this allows characters to be
+/* only level specific info follows, this allows characters to be
  * resurrected, the dungeon level info is not needed for a resurrection 
  */
     if (death) {
@@ -534,7 +540,7 @@ sv_write()
 	    if (c_ptr->cptr != 0) {
 		wr_byte((int8u) i);
 		wr_byte((int8u) j);
-		wr_byte(c_ptr->cptr);
+		wr_short((int16u) c_ptr->cptr); /* was wr_byte -CWS */
 	    }
 	}
     wr_byte((int8u) 0xFF);	   /* marks end of cptr info */
@@ -548,8 +554,8 @@ sv_write()
 	    }
 	}
     wr_byte(0xFF);		   /* marks end of tptr info */
-/*
- * must set counter to zero, note that code may write out two bytes
+
+/* must set counter to zero, note that code may write out two bytes
  * unnecessarily 
  */
     count = 0;
@@ -572,8 +578,8 @@ sv_write()
     wr_byte(prev_char);
 
 #ifdef MSDOS
-/*
- * must change graphics symbols for walls and floors back to default chars,
+
+/* must change graphics symbols for walls and floors back to default chars,
  * this is necessary so that if the user changes the graphics line, the
  * program will be able change all existing walls/floors to the new symbol 
  */
@@ -602,18 +608,14 @@ sv_write()
     wr_long((int32u) c_list[MAX_CREATURES - 1].spells);
     wr_long((int32u) c_list[MAX_CREATURES - 1].cdefense);
     {
-	int16u              temp;  /* fix player ghost's exp bug.  The mexp
-				    * field is really an int32u, but the
-				    * savefile was writing/ reading an
-				    * int16u.  Since I don't want to change
-				    * the savefile format, this insures that
-				    * the low bits of mexp are written (No
-				    * ghost should be worth more than 64K
-				    * (Melkor is only worth 60k!), but we
-				    * check anyway).  Using temp insures that
-				    * the low bits are all written, and works
-				    * perfectly with a similar fix when
-				    * loading a character. -CFT */
+	int16u temp;
+/* fix player ghost's exp bug.  The mexp field is really an int32u, but the
+ * savefile was writing/reading an int16u.  Since I don't want to change
+ * the savefile format, this insures that the low bits of mexp are written (No
+ * ghost should be worth more than 64K (Melkor is only worth 60k!), but we
+ * check anyway).  Using temp insures that the low bits are all written, and works
+ * perfectly with a similar fix when* loading a character. -CFT
+ */
 
 	if (c_list[MAX_CREATURES - 1].mexp > (int32u) 0xff00)
 	    temp = (int16u) 0xff00;
@@ -621,9 +623,9 @@ sv_write()
 	    temp = (int16u) c_list[MAX_CREATURES - 1].mexp;
 	wr_short((int16u) temp);
     }
-    wr_byte((int8u) c_list[MAX_CREATURES - 1].sleep);
+    wr_short((int8u) c_list[MAX_CREATURES - 1].sleep);
     wr_byte((int8u) c_list[MAX_CREATURES - 1].aaf);
-    wr_byte((int8u) c_list[MAX_CREATURES - 1].ac);
+    wr_short((int8u) c_list[MAX_CREATURES - 1].ac);
     wr_byte((int8u) c_list[MAX_CREATURES - 1].speed);
     wr_byte((int8u) c_list[MAX_CREATURES - 1].cchar);
     wr_bytes(c_list[MAX_CREATURES - 1].hd, 2);
@@ -638,11 +640,11 @@ sv_write()
 int 
 save_char()
 {
-    vtype               temp;
-    char               *tmp2;
+    vtype temp;
+    char *tmp2;
 
 #ifdef SECURE
-    bePlayer();
+    beGames();
 #endif
     if (death && NO_SAVE)
 	return TRUE;
@@ -658,18 +660,18 @@ save_char()
 	return FALSE;
     }
 #ifdef SECURE
-    beGames();
+    bePlayer();
 #endif
     return TRUE;
 }
 
 int 
 _save_char(fnam)
-    char               *fnam;
+char *fnam;
 {
-    vtype               temp;
-    int                 ok, fd;
-    int8u               char_tmp;
+    vtype temp;
+    int   ok, fd;
+    int8u char_tmp;
 
     if (log_index < 0)
 	return TRUE;		   /* Nothing to save. */
@@ -757,24 +759,21 @@ _save_char(fnam)
 
 int 
 get_char(generate)
-    int                *generate;
+int *generate;
 {
-    register int        i, j;
-    int                 fd, c, ok, total_count;
-    int32u              l, age, time_saved;
-    vtype               temp;
-    int16u              int16u_tmp;
-    register cave_type *c_ptr;
-    register recall_type *r_ptr;
-    struct misc        *m_ptr;
-    struct stats       *s_ptr;
+    int                    i, j, fd, c, ok, total_count;
+    int32u                 l, age, time_saved;
+    vtype                  temp;
+    int16u                 int16u_tmp;
+    register cave_type    *c_ptr;
+    register recall_type  *r_ptr;
+    struct misc           *m_ptr;
+    struct stats          *s_ptr;
     register struct flags *f_ptr;
-    store_type         *st_ptr;
-    int8u               char_tmp, ychar, xchar, count;
-    int8u               version_maj, version_min, patch_level;
+    store_type            *st_ptr;
+    int8u char_tmp, ychar, xchar, count;
 
-    free_turn_flag = TRUE;	   /* So a feeling isn't generated upon
-				    * reloading -DGK */
+    free_turn_flag = TRUE;	   /* So a feeling isn't generated upon reloading -DGK */
     nosignals();
     *generate = TRUE;
     fd = (-1);
@@ -832,12 +831,19 @@ get_char(generate)
 	xor_byte = 0;
 	rd_byte(&xor_byte);
 
-    /* COMPAT support savefiles from 5.0.14 to 5.0.17 */
-    /* support savefiles from 5.1.0 to present */
+/* This boneheadedness is a direct result of the fact that Angband 2.4
+ * had version constants of 5.2, not 2.4.  2.5 inherited this.  2.6 fixes
+ * the problem.  Note that there must never be a 5.2.x version of Angband,
+ * or else this code will get confused. -CWS
+ */
+	if ((version_maj == 5) && (version_min == 2)) {
+	  version_maj = 2;
+	  version_min = 5;
+	}
+
 	if ((version_maj != CUR_VERSION_MAJ)
 	    || (version_min > CUR_VERSION_MIN)
-	    || (version_min == CUR_VERSION_MIN && patch_level > PATCH_LEVEL)
-	    || (version_min == 0 && patch_level < 14)) {
+	    || (version_min == CUR_VERSION_MIN && patch_level > PATCH_LEVEL)) {
 	    prt("Sorry. This savefile is from a different version of Angband.",
 		2, 0);
 	    goto error;
@@ -996,7 +1002,13 @@ get_char(generate)
 	    prt("Loaded Recall Memory", 6, 0);
 	put_qio();
 	rd_short((int16u *) & log_index);
-	rd_long(&l);
+        rd_long(&l);
+	if ((version_maj >= 2) && (version_min >= 6)) {
+	  rd_long(&l);
+	  rd_long(&l);
+	  rd_long(&l);
+	}
+
 	if (to_be_wizard)
 	    prt("Loaded Options Memory", 7, 0);
 	put_qio();
@@ -1127,7 +1139,7 @@ get_char(generate)
 
 	    s_ptr = &py.stats;
 	    rd_shorts(s_ptr->max_stat, 6);
-	    if (version_maj <= 5 && version_min <=2 && patch_level <= 6)
+	    if (version_maj <= 2 && version_min <=5 && patch_level <= 6)
 		rd_shorts(s_ptr->cur_stat, 6);
 	    else
 		rd_bytes(s_ptr->cur_stat, 6);                   /* -TL */
@@ -1204,10 +1216,17 @@ get_char(generate)
 	    rd_byte(&f_ptr->nexus_resist);
 	    rd_byte(&f_ptr->blindness_resist);
 	    rd_byte(&f_ptr->nether_resist);
+	    if ((version_maj >= 2) && (version_min >= 6))
+		rd_byte(&f_ptr->fear_resist);
+	    else
+		f_ptr->fear_resist = 0;	/* sigh */
 
 	    rd_short((int16u *) & missile_ctr);
 	    rd_long((int32u *) & turn);
-	    old_turn = turn;	/* best we can do... -CWS */
+	    if ((version_maj >= 2) && (version_min >= 6))
+	      rd_long((int32u *) & old_turn);
+	    else
+	      old_turn = turn;	/* best we can do... -CWS */
 
 	    rd_short((int16u *) & inven_ctr);
 	    if (inven_ctr > INVEN_WIELD) {
@@ -1239,29 +1258,25 @@ get_char(generate)
 	    rd_short((int16u *) & noscore);
 	    rd_shorts(player_hp, MAX_PLAYER_LEVEL);
 
-	    if ((version_min >= 2)
-		|| (version_min == 1 && patch_level >= 3))
-		for (i = 0; i < MAX_STORES; i++) {
-		    st_ptr = &store[i];
-		    rd_long((int32u *) & st_ptr->store_open);
-		    rd_short((int16u *) & st_ptr->insult_cur);
-		    rd_byte(&st_ptr->owner);
-		    rd_byte(&st_ptr->store_ctr);
-		    rd_short(&st_ptr->good_buy);
-		    rd_short(&st_ptr->bad_buy);
-		    if (st_ptr->store_ctr > STORE_INVEN_MAX) {
-			prt("ERROR in store_ctr", 9, 0);
-			goto error;
-		    }
-		    for (j = 0; j < st_ptr->store_ctr; j++) {
-			rd_long((int32u *) & st_ptr->store_inven[j].scost);
-			rd_item(&st_ptr->store_inven[j].sitem);
-		    }
-		}
+	    for (i = 0; i < MAX_STORES; i++) {
+	      st_ptr = &store[i];
+	      rd_long((int32u *) & st_ptr->store_open);
+	      rd_short((int16u *) & st_ptr->insult_cur);
+	      rd_byte(&st_ptr->owner);
+	      rd_byte(&st_ptr->store_ctr);
+	      rd_short(&st_ptr->good_buy);
+	      rd_short(&st_ptr->bad_buy);
+	      if (st_ptr->store_ctr > STORE_INVEN_MAX) {
+		prt("ERROR in store_ctr", 9, 0);
+		goto error;
+	      }
+	      for (j = 0; j < st_ptr->store_ctr; j++) {
+		rd_long((int32u *) & st_ptr->store_inven[j].scost);
+		rd_item(&st_ptr->store_inven[j].sitem);
+	      }
+	    }
 
-	    if ((version_min >= 2)
-		|| (version_min == 1 && patch_level >= 3)) {
-		rd_long(&time_saved);
+	    rd_long(&time_saved);
 #ifndef SET_UID
 #ifndef ALLOW_FIDDLING
 		if (!to_be_wizard) {
@@ -1273,9 +1288,7 @@ get_char(generate)
 		}
 #endif
 #endif
-	    }
-	    if (version_min >= 2)
-		rd_string(died_from);
+	    rd_string(died_from);
 	}
 	if ((c = getc(fileptr)) == EOF || (l & 0x80000000L)) {
 	    if ((l & 0x80000000L) == 0) {
@@ -1313,10 +1326,8 @@ get_char(generate)
 		    py.flags.word_recall = 0;
 		dun_level = 0;	   /* Resurrect on the town level. */
 		character_generated = 1;
-	    /*
-	     * set noscore to indicate a resurrection, and don't enter wizard
-	     * mode 
-	     */
+
+	    /* set noscore to indicate a resurrection, and don't enter wizard mode */
 		to_be_wizard = FALSE;
 		noscore |= 0x1;
 	    } else {
@@ -1325,8 +1336,7 @@ get_char(generate)
 		old_turn = (-1);
 	    }
 	    put_qio();
-	/*
-	 * The log_index of the previous incarnation is here if later version
+	/* The log_index of the previous incarnation is here if later version
 	 * want to use it. For now, throw it away and get a new log. 
 	 */
 	    log_index = (-1);
@@ -1339,10 +1349,7 @@ get_char(generate)
 	prt("Restoring Character...", 0, 0);
 	put_qio();
 
-    /*
-     * only level specific info should follow, not present for dead
-     * characters 
-     */
+    /* only level specific info should follow, not present for dead characters */
 
 	rd_short((int16u *) & dun_level);
 	rd_short((int16u *) & char_row);
@@ -1358,7 +1365,15 @@ get_char(generate)
 	while (char_tmp != 0xFF) {
 	    ychar = char_tmp;
 	    rd_byte(&xchar);
-	    rd_byte(&char_tmp);
+
+    /* let's correctly fix the invisible monster bug  -CWS */
+	    if ((version_maj >= 2) && (version_min >= 6)) {
+		rd_short((int16u *) & int16u_tmp);
+		cave[ychar][xchar].cptr = int16u_tmp;
+	    } else {
+		rd_byte((int8u *) & char_tmp);
+		cave[ychar][xchar].cptr = char_tmp;
+	    }
 	    if (xchar > MAX_WIDTH || ychar > MAX_HEIGHT) {
 		vtype               t1;
 
@@ -1367,7 +1382,6 @@ get_char(generate)
 			(unsigned) xchar, (unsigned) ychar, (unsigned) char_tmp);
 		prt(t1, 11, 0);
 	    }
-	    cave[ychar][xchar].cptr = char_tmp;
 	    rd_byte(&char_tmp);
 	}
     /* read in the treasure ptr info */
@@ -1420,15 +1434,6 @@ get_char(generate)
 	}
 	for (i = MIN_MONIX; i < mfptr; i++) {
 	    rd_monster(&m_list[i]);
-	/* let's fix the infamous monster heal bug -CWS */
-	    if ((c_list[m_list[i].mptr].cdefense & MAX_HP) || be_nasty)
-		m_list[i].maxhp = max_hp(c_list[m_list[i].mptr].hd);
-	    else
-		m_list[i].maxhp = pdamroll(c_list[m_list[i].mptr].hd);
-	    if (m_list[i].hp > m_list[i].maxhp)
-		m_list[i].maxhp = m_list[i].maxhp;
-
-	    m_list[i].monfear = 0; /* this is not saved either -CWS */
 	}
 #ifdef MSDOS
     /* change walls and floors to graphic symbols */
@@ -1450,30 +1455,41 @@ get_char(generate)
 	rd_long((int32u *) & (c_list[MAX_CREATURES - 1].spells));
 	rd_long((int32u *) & (c_list[MAX_CREATURES - 1].cdefense));
 	{
-	    int16u              t1;/* fix player ghost's exp bug.  The mexp
-				    * field is really an int32u, but the
-				    * savefile was writing/ reading an
-				    * int16u.  Since I don't want to change
-				    * the savefile format, this insures that
-				    * the mexp field is loaded, and that the
-				    * "high bits" of mexp do not contain
-				    * garbage values which could mean that
-				    * player ghost are worth millions of exp.
-				    * -CFT */
+	    int16u t1;
+/* fix player ghost's exp bug.  The mexp field is really an int32u, but the
+ * savefile was writing/ reading an int16u.  Since I don't want to change
+ * the savefile format, this insures that the mexp field is loaded, and that
+ * the "high bits" of mexp do not contain garbage values which could mean that
+ * player ghost are worth millions of exp. -CFT
+ */
 
 	    rd_short((int16u *) & t1);
 	    c_list[MAX_CREATURES - 1].mexp = (int32u) t1;
 	}
-	rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].sleep));
+
+/* more stupid size bugs that would've never been needed if these variables
+ * had been given enough space in the first place -CWS
+ */
+	if ((version_maj >= 2) && (version_min >= 6))
+	    rd_short((int16u *) & (c_list[MAX_CREATURES - 1].sleep));
+	else
+	    rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].sleep));
+
 	rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].aaf));
-	rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].ac));
+
+	if ((version_maj >= 2) && (version_min >= 6))
+	    rd_short((int16u *) & (c_list[MAX_CREATURES - 1].ac));
+	else
+	    rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].ac));
+
 	rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].speed));
 	rd_byte((int8u *) & (c_list[MAX_CREATURES - 1].cchar));
+
 	rd_bytes((int8u *) (c_list[MAX_CREATURES - 1].hd), 2);
+
 	rd_bytes((int8u *) (c_list[MAX_CREATURES - 1].damage), sizeof(attid) * 4);
 	rd_short((int16u *) & (c_list[MAX_CREATURES - 1].level));
-	*generate = FALSE;	   /* We have restored a cave - no need to
-				    * generate. */
+	*generate = FALSE;	   /* We have restored a cave - no need to generate. */
 
 	if ((version_min == 1 && patch_level < 3)
 	    || (version_min == 0))
@@ -1496,10 +1512,7 @@ get_char(generate)
 	    }
 
     /* read the time that the file was saved */
-	if (version_min == 0 && patch_level < 16)
-	    time_saved = 0;	   /* no time in file, clear to zero */
-	else if (version_min == 1 && patch_level < 3)
-	    rd_long(&time_saved);
+	rd_long(&time_saved);
 
 	if (ferror(fileptr)) {
 	    prt("FILE ERROR", 17, 0);
@@ -1556,10 +1569,8 @@ closefiles:
 		for (i = 0; i < age; i++)
 		    store_maint();
 	    }
-	/*
-	 * if (noscore) msg_print("This save file cannot be used to get on
-	 * the score board."); 
-	 */
+
+/* if (noscore) msg_print("This save file cannot be used to get on the score board."); */
 
 	    if (version_maj != CUR_VERSION_MAJ
 		|| version_min != CUR_VERSION_MIN) {
@@ -1582,8 +1593,7 @@ closefiles:
 		unlink(savefile);
 		return TRUE;
 	    } else {
-		return FALSE;	   /* Only restored options and monster
-				    * memory. */
+		return FALSE;	   /* Only restored options and monster memory. */
 	    }
 	}
     }
@@ -1602,7 +1612,7 @@ closefiles:
 
 static void 
 wr_byte(c)
-    int8u               c;
+int8u c;
 {
     xor_byte ^= c;
     (void)putc((int)xor_byte, fileptr);
@@ -1610,7 +1620,7 @@ wr_byte(c)
 
 static void 
 wr_short(s)
-    int16u              s;
+int16u s;
 {
     xor_byte ^= (s & 0xFF);
     (void)putc((int)xor_byte, fileptr);
@@ -1620,7 +1630,7 @@ wr_short(s)
 
 static void 
 wr_long(l)
-    register int32u     l;
+register int32u l;
 {
     xor_byte ^= (l & 0xFF);
     (void)putc((int)xor_byte, fileptr);
@@ -1634,11 +1644,11 @@ wr_long(l)
 
 static void 
 wr_bytes(c, count)
-    int8u              *c;
-    register int        count;
+int8u       *c;
+register int count;
 {
-    register int        i;
-    register int8u     *ptr;
+    register int    i;
+    register int8u *ptr;
 
     ptr = c;
     for (i = 0; i < count; i++) {
@@ -1649,7 +1659,7 @@ wr_bytes(c, count)
 
 static void 
 wr_string(str)
-    register char      *str;
+register char *str;
 {
     while (*str != '\0') {
 	xor_byte ^= *str++;
@@ -1661,8 +1671,8 @@ wr_string(str)
 
 static void 
 wr_shorts(s, count)
-    int16u             *s;
-    register int        count;
+int16u      *s;
+register int count;
 {
     register int        i;
     register int16u    *sptr;
@@ -1678,7 +1688,7 @@ wr_shorts(s, count)
 
 static void 
 wr_item(item)
-    register inven_type *item;
+register inven_type *item;
 {
     wr_short(item->index);
     wr_byte(item->name2);
@@ -1704,9 +1714,10 @@ wr_item(item)
 
 static void 
 wr_monster(mon)
-    register monster_type *mon;
+register monster_type *mon;
 {
     wr_short((int16u) mon->hp);
+    wr_short((int16u) mon->maxhp); /* added -CWS */
     wr_short((int16u) mon->csleep);
     wr_short((int16u) mon->cspeed);
     wr_short(mon->mptr);
@@ -1716,13 +1727,14 @@ wr_monster(mon)
     wr_byte(mon->ml);
     wr_byte(mon->stunned);
     wr_byte(mon->confused);
+    wr_byte(mon->monfear);	/* added -CWS */
 }
 
 static void 
 rd_byte(ptr)
-    int8u              *ptr;
+int8u *ptr;
 {
-    int8u               c;
+    int8u c;
 
     c = getc(fileptr) & 0xFF;
     *ptr = c ^ xor_byte;
@@ -1731,10 +1743,10 @@ rd_byte(ptr)
 
 static void 
 rd_short(ptr)
-    int16u             *ptr;
+int16u *ptr;
 {
-    int8u               c;
-    int16u              s;
+    int8u  c;
+    int16u s;
 
     c = (getc(fileptr) & 0xFF);
     s = c ^ xor_byte;
@@ -1745,10 +1757,10 @@ rd_short(ptr)
 
 static void 
 rd_long(ptr)
-    int32u             *ptr;
+int32u *ptr;
 {
-    register int32u     l;
-    register int8u      c;
+    register int32u l;
+    register int8u  c;
 
     c = (getc(fileptr) & 0xFF);
     l = c ^ xor_byte;
@@ -1763,12 +1775,11 @@ rd_long(ptr)
 
 static void 
 rd_bytes(ptr, count)
-    int8u              *ptr;
-    int                 count;
+int8u *ptr;
+int    count;
 {
-    int                 i;
-    int8u               c;
-    int8u               nc;
+    int   i;
+    int8u c, nc;
 
     for (i = 0; i < count; i++) {
 	c = (getc(fileptr) & 0xFF);
@@ -1781,9 +1792,9 @@ rd_bytes(ptr, count)
 
 static void 
 rd_string(str)
-    char               *str;
+char *str;
 {
-    register int8u      c;
+    register int8u c;
 
     do {
 	c = (getc(fileptr) & 0xFF);
@@ -1795,8 +1806,8 @@ rd_string(str)
 
 static void 
 rd_shorts(ptr, count)
-    int16u             *ptr;
-    register int        count;
+int16u      *ptr;
+register int count;
 {
     register int        i;
     register int16u    *sptr;
@@ -1815,7 +1826,7 @@ rd_shorts(ptr, count)
 
 static void 
 rd_item(item)
-    register inven_type *item;
+register inven_type *item;
 {
     rd_short(&item->index);
     rd_byte(&item->name2);
@@ -1841,9 +1852,16 @@ rd_item(item)
 
 static void 
 rd_monster(mon)
-    register monster_type *mon;
+register monster_type *mon;
 {
     rd_short((int16u *) & mon->hp);
+    if ((version_maj >= 2) && (version_min >= 6))
+	rd_short((int16u *) & mon->maxhp);
+    else {
+	/* let's fix the infamous monster heal bug -CWS */
+	mon->maxhp = mon->hp;
+    }
+
     rd_short((int16u *) & mon->csleep);
     rd_short((int16u *) & mon->cspeed);
     rd_short(&mon->mptr);
@@ -1853,4 +1871,8 @@ rd_monster(mon)
     rd_byte(&mon->ml);
     rd_byte(&mon->stunned);
     rd_byte(&mon->confused);
+    if ((version_maj >= 2) && (version_min >= 6))
+	rd_byte((int8u *) & mon->monfear);
+    else
+	mon->monfear = 0; /* this is not saved either -CWS */
 }
